resource "google_compute_health_check" "https-probe" {
  name               = "https-probe-${random_string.deployment_id.result}"
  check_interval_sec = 5
  healthy_threshold  = 2
  tcp_health_check {
    port = 443
  }
  #region = var.region
}

resource "google_compute_global_address" "lb-ip" {
  name         = "lb-ip-${random_string.deployment_id.result}"
  address_type = "EXTERNAL"
}

#Forward 443
resource "google_compute_global_forwarding_rule" "fw-tcp" {
  name                  = "fw-tcp-${random_string.deployment_id.result}"
  ip_address            = google_compute_global_address.lb-ip.address
  ip_protocol           = "TCP"
  port_range            = "443-443"
  target                = google_compute_target_tcp_proxy.fw-proxy.id
  load_balancing_scheme = "EXTERNAL"
}

resource "google_compute_target_tcp_proxy" "fw-proxy" {
  name            = "fw-tcp-${random_string.deployment_id.result}-proxy"
  backend_service = google_compute_backend_service.tcp-backend.id
}

resource "google_compute_backend_service" "tcp-backend" {
  backend {
    group                        = google_compute_region_instance_group_manager.mig-servers.instance_group
    balancing_mode               = "CONNECTION"
    max_connections_per_instance = 30000
  }
  backend {
    group                        = google_compute_region_instance_group_manager.mig-agents.instance_group
    balancing_mode               = "CONNECTION"
    max_connections_per_instance = 30000
  }

  backend {
    group                        = google_compute_region_instance_group_manager.mig-asrobots-agents.instance_group
    balancing_mode               = "CONNECTION"
    max_connections_per_instance = 30000
  }

  dynamic "backend" {
    for_each = (var.gpu_agent_count > 0) ? [1] : []
    content {
      group                        = google_compute_region_instance_group_manager.mig-gpus[0].instance_group
      balancing_mode               = "CONNECTION"
      max_connections_per_instance = 3000
    }
  }

  load_balancing_scheme = "EXTERNAL"
  health_checks         = [google_compute_health_check.https-probe.id]
  name                  = "tcp-backend-${random_string.deployment_id.result}"
  port_name             = "https"
  protocol              = "TCP"
}
