#Forward servers
resource "google_compute_address" "lb-registration-ip" {
  name         = "lb-registration-ip-${random_string.deployment_id.result}"
  address_type = "INTERNAL"
  subnetwork   = google_compute_subnetwork.vnet-subnet.self_link
}

resource "google_compute_region_health_check" "rke2-probe" {
  name               = "rke2-probe-${random_string.deployment_id.result}"
  check_interval_sec = 5
  healthy_threshold  = 2
  tcp_health_check {
    port = 9345
  }
  region = var.region
}

resource "google_compute_forwarding_rule" "fw-servers-registration" {
  name                  = "fw-servers-registration-${random_string.deployment_id.result}"
  ip_address            = google_compute_address.lb-registration-ip.address
  ip_protocol           = "TCP"
  ports                 = ["9345", "6443"]
  backend_service       = google_compute_region_backend_service.registration-backend.id
  load_balancing_scheme = "INTERNAL"
  allow_global_access   = true
  subnetwork            = google_compute_subnetwork.vnet-subnet.self_link
}

resource "google_compute_region_backend_service" "registration-backend" {
  backend {
    group          = google_compute_region_instance_group_manager.mig-servers.instance_group
    balancing_mode = "CONNECTION"
  }

  health_checks         = [google_compute_region_health_check.rke2-probe.id]
  name                  = "registration-backend-${random_string.deployment_id.result}"
  protocol              = "TCP"
}

#Forward proxies
resource "google_compute_address" "lb-proxies-ip" {
  name         = "lb-proxies-ip-${random_string.deployment_id.result}"
  address_type = "INTERNAL"
  subnetwork   = google_compute_subnetwork.vnet-subnet.self_link
}

resource "google_compute_forwarding_rule" "fw-proxies-registration" {
  name                  = "fw-proxies-registration-${random_string.deployment_id.result}"
  ip_address            = google_compute_address.lb-proxies-ip.address
  ip_protocol           = "TCP"
  ports                 = ["9345", "6443"]
  backend_service       = google_compute_region_backend_service.proxies-backend.id
  load_balancing_scheme = "INTERNAL"
  allow_global_access   = true
  subnetwork            = google_compute_subnetwork.vnet-subnet.self_link
}

resource "google_compute_region_backend_service" "proxies-backend" {
  backend {
    group          = google_compute_region_instance_group_manager.mig-proxies.instance_group
    balancing_mode = "CONNECTION"
  }

  health_checks         = [google_compute_region_health_check.rke2-probe.id]
  name                  = "proxies-backend-${random_string.deployment_id.result}"
  protocol              = "TCP"
}

resource "google_compute_region_instance_group_manager" "mig-proxies" {
  name               = "proxies-manager-${random_string.deployment_id.result}"
  base_instance_name = "proxy-${random_string.deployment_id.result}"
  target_size        = (var.server_count >= 3) ? 3 : 1
  wait_for_instances = true
  region             = var.region

  version {
    name              = "proxies"
    instance_template = google_compute_instance_template.proxy.id
  }
}

resource "google_compute_instance_template" "proxy" {
  name         = "proxy-template-${random_string.deployment_id.result}"
  machine_type = "n1-standard-1"
  region       = var.region
  can_ip_forward = true

  disk {
    boot         = true
    auto_delete  = true
    source_image = "debian-cloud/debian-10"
  }

  network_interface {
    network    = google_compute_network.vnet.self_link
    subnetwork = google_compute_subnetwork.vnet-subnet.self_link
  }


  metadata = {
    "ssh-keys" = "${var.ssh_user}:${local.ssh_pub_key}"
  }

  metadata_startup_script = data.template_file.init-proxy.rendered
  lifecycle {
    ignore_changes = [
      metadata_startup_script
    ]
  }
}
