resource "google_compute_network" "vnet" {
  auto_create_subnetworks = false
  name                    = "vnet-${random_string.deployment_id.result}"
}
resource "google_compute_subnetwork" "vnet-subnet" {
  network       = google_compute_network.vnet.name
  name          = "${google_compute_network.vnet.name}-0"
  region        = var.region
  ip_cidr_range = "10.0.0.0/16"
}

resource "google_compute_router" "router" {
  name    = "router-${random_string.deployment_id.result}"
  region  = google_compute_subnetwork.vnet-subnet.region
  network = google_compute_network.vnet.id
}

resource "google_compute_router_nat" "nat" {
  name                               = "router-nat-${random_string.deployment_id.result}"
  router                             = google_compute_router.router.name
  region                             = google_compute_router.router.region
  nat_ip_allocate_option             = "AUTO_ONLY"
  source_subnetwork_ip_ranges_to_nat = "LIST_OF_SUBNETWORKS"

  subnetwork {
    name                    = google_compute_subnetwork.vnet-subnet.self_link
    source_ip_ranges_to_nat = ["ALL_IP_RANGES"]
  }
}

resource "google_compute_firewall" "ssh_bastion" {
  name          = "ssh-bastion-${random_string.deployment_id.result}"
  network       = google_compute_network.vnet.self_link
  source_ranges = ["0.0.0.0/0"]

  priority = 1000
  allow {
    ports    = ["22"]
    protocol = "tcp"
  }
}

resource "google_compute_firewall" "ssh_nodes" {
  name        = "ssh-nodes-${random_string.deployment_id.result}"
  network     = google_compute_network.vnet.self_link
  source_tags = ["bastion"]
  priority    = 1001
  allow {
    ports    = ["22"]
    protocol = "tcp"
  }
}

resource "google_compute_firewall" "allow-health-probes" {
  name          = "allow-health-probes-${random_string.deployment_id.result}"
  network       = google_compute_network.vnet.self_link
  source_ranges = ["35.191.0.0/16", "209.85.152.0/22", "209.85.204.0/22"]
  priority      = 999
  allow {
    protocol = "tcp"
  }
}

resource "google_compute_firewall" "inbound_https" {
  name          = "allow-https-${random_string.deployment_id.result}"
  network       = google_compute_network.vnet.self_link
  priority      = 1003
  source_ranges = ["0.0.0.0/0"]
  allow {
    protocol = "tcp"
    ports    = ["443"]
  }
}

resource "google_compute_firewall" "internal_traffic" {
  name          = "allow-internal-traffic-${random_string.deployment_id.result}"
  network       = google_compute_network.vnet.self_link
  priority      = 1004
  source_ranges = [google_compute_subnetwork.vnet-subnet.ip_cidr_range]
  allow {
    protocol = "tcp"
    ports    = ["10250", "2379", "2380", "3000-32767", "1433"]
  }
  allow {
    protocol = "udp"
    ports    = ["8472"]
  }
}

resource "google_compute_firewall" "registration_traffic" {
  name          = "allow-registration-traffic-${random_string.deployment_id.result}"
  network       = google_compute_network.vnet.self_link
  priority      = 1005
  source_ranges = ["0.0.0.0/0"]
  allow {
    protocol = "tcp"
    ports    = ["6443", "9345"]
  }
}