${install_prereqs}
set -eu

export PATH=$PATH:/var/lib/rancher/rke2/bin:/opt/UiPathAutomationSuite/Installer/bin:/usr/local/bin
export KUBECONFIG="/etc/rancher/rke2/rke2.yaml"

function install_uipath() {
  local registration_url
  local status

  registration_url="$(jq -r ".fixed_rke_address" <"/opt/UiPathAutomationSuite/Installer/cluster_config.json")"

  echo "Installing as Agent"

  registration_status=""
  local try=0
  local maxtry=60

  registration_status=$(curl -w '%%{response_code}' -sk -o /dev/null https://"$registration_url":9345/ping) || true
  while [[ "$registration_status" != "200" ]] && ((try != maxtry)); do
    try=$((try + 1))
    registration_status=$(curl -w '%%{response_code}' -sk -o /dev/null https://"$registration_url":9345/ping) || true
    echo "Trying to reach $registration_url ==== $try/$maxtry" && sleep 30
  done

  [[ "$registration_status" == "200" ]] || (echo "Primary server failed to start" && exit 1)
  echo "Primary server is up. Waiting for components to install on primary server"
  # Install infra
  try=0
  maxtry=5
  status="notready"
  while [[ "$status" != "ready" ]] && ((try != maxtry)); do
    try=$((try + 1))
    echo "Trying to install infra ==== $try/$maxtry"
    /opt/UiPathAutomationSuite/Installer/install-uipath.sh -i /opt/UiPathAutomationSuite/Installer/cluster_config.json -o /opt/UiPathAutomationSuite/Installer/output.json -k -j ${node_type} --accept-license-agreement && status="ready"
    sleep 30
  done
  
  if [[ "$status" == "ready" ]]; then
      echo "Successfuly installed infra, waiting for the other nodes"
  else
      echo "Failed to install infra $?"
      curl -s -X PUT --data "FAILED" http://metadata.google.internal/computeMetadata/v1/instance/guest-attributes/installation/app_installer -H "Metadata-Flavor: Google"
      exit 1
  fi
  curl -s -X PUT --data "SUCCESS" http://metadata.google.internal/computeMetadata/v1/instance/guest-attributes/installation/app_installer -H "Metadata-Flavor: Google"
}

install_status=$(curl -s http://metadata.google.internal/computeMetadata/v1/instance/guest-attributes/installation/app_installer -H "Metadata-Flavor: Google")
if [ "$install_status" != "SUCCESS" ]; then
    install_uipath > /opt/UiPathAutomationSuite/install.logs 2>&1
else
    echo "Installer already run"
fi