#!/bin/bash

function get_fixed_address() {
    project_id=$(curl -s "http://metadata.google.internal/computeMetadata/v1/project/numeric-project-id" -H "Metadata-Flavor: Google")
    instance_group_id="projects/$project_id/regions/$1/instanceGroupManagers/$2"
    
    fixed_address=$(gcloud compute instances list --filter="metadata.items.key['created-by']['value']=$instance_group_id" --sort-by=INTERNAL_IP --format="table[no-heading](ID, INTERNAL_IP)" | head -n 1 | awk '{print $2}')
    echo $fixed_address
}

function main(){
    local fixed_address=$(get_fixed_address "$1" "$2")
    local try=0
    local maxtry=600
    local install_status=""
    local exit_code=1
    local ssh_counter=0
    while ((try != maxtry)) ; do
        install_status=$(ssh -i /home/$3/.ssh/private_key -o "StrictHostKeyChecking=no" $3@$fixed_address 'sudo journalctl -u google-startup-scripts.service | grep "startup-script exit status"')
        if [ "$install_status" != "" ] && [ "$ssh_counter" -ge 3 ]; then
            break
        fi
        [[ "$install_status" != "" ]] && ssh_counter=$((ssh_counter + 1))
        try=$((try + 1))
        echo "Waiting for deployment to be ready ==== $try/$maxtry" && sleep 30
    done
    if [ "$install_status" != "" ]; then
        exit_code=$(echo $install_status | awk '{print $NF}')
    fi
    exit $exit_code
}

main "$@"