resource "random_password" "root_db_password" {
  length           = 32
  special          = true
  override_special = "!%^"
}

resource "google_secret_manager_secret" "db-credentials-secret" {
  secret_id = "db-credentials-${random_string.deployment_id.result}"
  replication {
    automatic = true
  }
}

resource "google_secret_manager_secret_iam_binding" "allow-db-credential-read" {
  secret_id = google_secret_manager_secret.db-credentials-secret.id
  role = "roles/secretmanager.secretAccessor"
  members = [
    "serviceAccount:${data.google_compute_default_service_account.default.email}",
  ]
}

resource "google_secret_manager_secret_version" "db-credentials-version" {
  secret = google_secret_manager_secret.db-credentials-secret.id
  secret_data = jsonencode({
      user = "sqlserver"
      password = random_password.root_db_password.result
  })
}

resource "random_password" "default_tenant_password" {
  length           = 28
  special          = true
  override_special = "@#$"
}
resource "google_secret_manager_secret" "as-default-credentials-secret" {
  secret_id = "as-default-credentials-${random_string.deployment_id.result}"

  replication {
    automatic = true
  }
}

resource "google_secret_manager_secret_iam_binding" "allow-as-default-credentials-read" {
  secret_id = google_secret_manager_secret.as-default-credentials-secret.id
  role = "roles/secretmanager.secretAccessor"
  members = [
    "serviceAccount:${data.google_compute_default_service_account.default.email}",
  ]
}

resource "google_secret_manager_secret_version" "as-default-credentials-version" {
  secret = google_secret_manager_secret.as-default-credentials-secret.id
  secret_data = jsonencode({
      user = "orgadmin"
      password = "u${random_password.default_tenant_password.result}"
  })
}

resource "google_secret_manager_secret" "as-host-credentials-secret" {
  secret_id = "as-host-credentials-${random_string.deployment_id.result}"

  replication {
    automatic = true
  }
}

resource "google_secret_manager_secret_iam_binding" "allow-as-host-credentials-read" {
  secret_id = google_secret_manager_secret.as-host-credentials-secret.id
  role = "roles/secretmanager.secretAccessor"
  members = [
    "serviceAccount:${data.google_compute_default_service_account.default.email}",
  ]
}

resource "google_secret_manager_secret_version" "as-host-credentials-version" {
  secret = google_secret_manager_secret.as-host-credentials-secret.id
  secret_data = jsonencode({
      user = "orgadmin"
      password = "u${random_password.default_tenant_password.result}"
  })
}

resource "random_password" "argo_password" {
  length           = 32
  special          = true
  override_special = "@#$"
}

resource "random_password" "argo_user_password" {
  length           = 32
  special          = true
  override_special = "@#$"
}

resource "google_secret_manager_secret" "argo-credentials-secret" {
  secret_id = "argocd-credentials-${random_string.deployment_id.result}"

  replication {
    automatic = true
  }
}

resource "google_secret_manager_secret" "argo-user-credentials-secret" {
  secret_id = "argocd-user-credentials-${random_string.deployment_id.result}"

  replication {
    automatic = true
  }
}

resource "google_secret_manager_secret_iam_binding" "allow-argo-credentials-read" {
  secret_id = google_secret_manager_secret.argo-credentials-secret.id
  role = "roles/secretmanager.secretAccessor"
  members = [
    "serviceAccount:${data.google_compute_default_service_account.default.email}",
  ]
}

resource "google_secret_manager_secret_version" "argo-credentials-version" {
  secret = google_secret_manager_secret.argo-credentials-secret.id
  secret_data = jsonencode({
      user = "admin"
      password = random_password.argo_password.result
  })
}

resource "google_secret_manager_secret_iam_binding" "allow-argo-user-credentials-read" {
  secret_id = google_secret_manager_secret.argo-user-credentials-secret.id
  role = "roles/secretmanager.secretAccessor"
  members = [
    "serviceAccount:${data.google_compute_default_service_account.default.email}",
  ]
}

resource "google_secret_manager_secret_version" "argo-user-credentials-version" {
  secret = google_secret_manager_secret.argo-user-credentials-secret.id
  secret_data = jsonencode({
      user = "admin"
      password = random_password.argo_user_password.result
  })
}