locals {
  is_production_pm = var.install_process_mining && (var.server_count >= 3)
}

resource "google_compute_global_address" "sql_private_ip_address" {
  name          = "private-ip-address-${random_string.deployment_id.result}"
  purpose       = "VPC_PEERING"
  address_type  = "INTERNAL"
  prefix_length = 24
  network       = google_compute_network.vnet.self_link
}

resource "google_service_networking_connection" "private_vpc_connection" {
  network                 = google_compute_network.vnet.self_link
  service                 = "servicenetworking.googleapis.com"
  reserved_peering_ranges = flatten([[google_compute_global_address.sql_private_ip_address.name], local.is_production_pm ? [google_compute_global_address.pm_sql_private_ip_address[0].name] : []])
}

resource "google_sql_database_instance" "sql_instance" {
  name                = "db-instance-${random_string.deployment_id.result}"
  database_version    = "SQLSERVER_2019_ENTERPRISE"
  region              = var.region
  root_password       = random_password.root_db_password.result
  deletion_protection = false

  settings {
    disk_size = 1000
    tier      = "db-custom-8-32768"
    ip_configuration {
      ipv4_enabled = false
      private_network = google_compute_network.vnet.self_link
      authorized_networks {
        value = "0.0.0.0/0"
      }
    }
  }

  depends_on = [
    google_service_networking_connection.private_vpc_connection
  ]
}

resource "google_compute_global_address" "pm_sql_private_ip_address" {
  count = local.is_production_pm ? 1 : 0
  name          = "pm-private-ip-address-${random_string.deployment_id.result}"
  purpose       = "VPC_PEERING"
  address_type  = "INTERNAL"
  prefix_length = 24
  network       = google_compute_network.vnet.self_link
}

resource "google_sql_database_instance" "pm_sql_instance" {
  count = local.is_production_pm ? 1 : 0
  name                = "pm-db-instance-${random_string.deployment_id.result}"
  database_version    = "SQLSERVER_2019_ENTERPRISE"
  region              = var.region
  root_password       = random_password.root_db_password.result
  deletion_protection = false

  settings {
    disk_size = 100
    tier      = "db-custom-16-32768"
    ip_configuration {
      ipv4_enabled = false
      private_network = google_compute_network.vnet.self_link
      authorized_networks {
        value = "0.0.0.0/0"
      }
    }
  }

  depends_on = [
    google_service_networking_connection.private_vpc_connection
  ]
}