variable "project_id" {
  type        = string
  description = "Project in which the resoursce will be deployed."
}

variable "server_count" {
  type        = number
  description = "Number of server VMs, must be odd"
  default     = 3

  validation {
    condition     = var.server_count > 0 && var.server_count % 2 == 1
    error_message = "Number of servers should be odd and greater than 0."
  }
}

variable "agent_count" {
  type        = number
  description = "Number of agent VMs"
  default     = 1

  validation {
    condition     = var.agent_count >= 0
    error_message = "Number of agent should be greater than or equal to 0."
  }
}

variable "asrobots_agent_count" {
  type        = number
  description = "Number of agent VMs"
  default     = 0

  validation {
    condition     = var.asrobots_agent_count >= 0
    error_message = "Number of agent should be greater than or equal to 0."
  }
}


variable "gpu_agent_count" {
  type        = number
  description = "Number of GPU agent VMs"
  default     = 0

  validation {
    condition     = var.gpu_agent_count >= 0
    error_message = "Number of GPU agent should be greater than or equal to 0."
  }
}

variable "gpu_instance_type" {
  type        = string
  default     = "n2-standard-16"
  description = "Instance type of agent VMs."
}

variable "gpu_type" {
  type        = string
  default     = "nvidia-tesla-t4"
  description = "GPU type for the nodes."
}

variable "server_instance_type" {
  type        = string
  default     = "n2-standard-32"
  description = "Instance type of server VMs."
}

variable "agent_instance_type" {
  type        = string
  default     = "n2-standard-16"
  description = "Instance type of agents VMs."
}

variable "asrobots_agent_instance_type" {
  type        = string
  default     = "n2-standard-16"
  description = "Instance type of Automation Suite robots dedicated agents."
}


variable "vm_custom_image" {
  type        = string
  default     = ""
  description = "Name of the custom image you want to use for the VM's. Leave empty to default to latest RHEL 8 GCP image."
}
variable "ssh_private_key_path" {
  type        = string
  description = "Path to the ssh private key used to access VMs."
}

variable "ssh_pub_key_path" {
  type        = string
  description = "Path to the ssh public key used to access VMs."
}

variable "ssh_user" {
  type        = string
  description = "Ssh user used to log in VMs."
}

variable "region" {
  type        = string
  description = "Region where the resources are deployed."
}

variable "zone" {
  type        = string
  description = "Default zone where regional resources are deployed."
}

variable "installer_version" {
  type        = string
  default     = "2023.10.0"
  description = "Automation Suite installer version."
  validation {
    condition     = contains(["2023.10.0"], var.installer_version)
    error_message = "Only these versions are supported: 2023.10.0."
  }
}

variable "installer_url" {
  type        = string
  default     = ""
  description = "Automation Suite installer download URL. If used it will override the download URL based on the installer_version parameter."
}
variable "lb_fqdn" {
  type        = string
  description = "Url of the load balancer."
}

variable "perform_installation" {
  type        = bool
  default     = true
  description = "Automatically install Automation Suite on the provided infrastructure."
}
variable "install_orchestrator" {
  type        = bool
  default     = true
  description = "Install Orchestrator."
}

variable "install_aicenter" {
  type        = bool
  default     = true
  description = "Install AI Center."
}

variable "install_documentunderstanding" {
  type        = bool
  default     = true
  description = "Install Document Understanding."
}

variable "install_insights" {
  type        = bool
  default     = true
  description = "Install Insights."
}

variable "install_test_manager" {
  type        = bool
  default     = true
  description = "Install Test Manager."
}

variable "install_automation_ops" {
  type        = bool
  default     = true
  description = "Install Automation Ops."
}

variable "install_automation_hub" {
  type        = bool
  default     = true
  description = "Install Automation Hub."
}

variable "install_data_service" {
  type        = bool
  default     = true
  description = "Install Data Service."
}

variable "install_process_mining" {
  type        = bool
  default     = true
  description = "Install Process Mining."
}

variable "install_as_robots" {
  type        = bool
  default     = true
  description = "Install Automation Suite Robots."
}


variable "install_apps" {
  type        = bool
  default     = true
  description = "Install Apps."
}

variable "install_action_center" {
  type        = bool
  default     = true
  description = "Install Action Center."
}
variable "install_task_mining" {
  type        = bool
  default     = true
  description = "Install Task Mining."
}

variable "accept_license_agreement" {
  type        = bool
  default     = false
  description = "Use of paid UiPath products and services is subject to the licensing agreement executed between you and UiPath. Unless otherwise indicated by UiPath, use of free UiPath products is subject to the associated licensing agreement available here: https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website). By setting the argument accept_licesnse_agreement as true, you agree to the applicable licensing agreement."
  validation {
    condition     = var.accept_license_agreement
    error_message = "Use of paid UiPath products and services is subject to the licensing agreement executed between you and UiPath. Unless otherwise indicated by UiPath, use of free UiPath products is subject to the associated licensing agreement available here: https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website). By setting the argument accept_licesnse_agreement as true, you agree to the applicable licensing agreement."
  }
}
